@@ -18,33 +18,32 @@
  ***************************************************************************/
 
 #include "form.h"
-#include <QtXml/QDomDocument>
+#include <QDomDocument>
 
-#include <QtCore/QByteRef>
-#include <QtCore/QBuffer>
-#include <QtCore/QRegExp>
-#include <QtCore/QFile>
-#include <QtCore/QArgument>
-#include <QtCore/QMetaEnum>
-#include <QtWidgets/QAction>
-#include <QtWidgets/QDialogButtonBox>
-#include <QtGui/QKeyEvent>
-#include <QtWidgets/QDialog>
-#include <QtWidgets/QBoxLayout>
-#include <QtWidgets/QStackedLayout>
-#include <QtWidgets/QSizePolicy>
-#include <QtWidgets/QApplication>
-#include <QtWidgets/QProgressBar>
+#include <QByteRef>
+#include <QBuffer>
+#include <QRegExp>
+#include <QFile>
+#include <QArgument>
+#include <QMetaEnum>
+#include <QAction>
+#include <QDialogButtonBox>
+#include <QKeyEvent>
+#include <QDialog>
+#include <QBoxLayout>
+#include <QStackedLayout>
+#include <QSizePolicy>
+#include <QApplication>
+#include <QProgressBar>
 //#include <QProgressDialog>
-#include <QtWidgets/QPushButton>
-#include <QtWidgets/QTextBrowser>
+#include <QPushButton>
+#include <QTextBrowser>
 #include <QtUiTools/QUiLoader>
-#include <QtGui/QTextCursor>
-#include <QtGui/QTextBlock>
-#include <QtCore/QTime>
-#include <QtCore/QUrl>
+#include <QTextCursor>
+#include <QTextBlock>
+#include <QElapsedTimer>
 
-#include <QtCore/QDebug>
+#include <QDebug>
 #include <klocalizedstring.h>
 //#include <kurlcombobox.h>
 //#include <kdiroperator.h>
@@ -128,7 +127,7 @@ FormFileWidget::FormFileWidget(QWidget *parent, const QString &startDirOrVariabl
 {
     QVBoxLayout *layout = new QVBoxLayout(this);
     layout->setSpacing(0);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     setLayout(layout);
 
     d->filewidget = new KFileWidget(QUrl(startDirOrVariable), this);
@@ -231,7 +230,7 @@ public:
     QTextBrowser *browser;
     QProgressBar *bar;
     bool gotCanceled;
-    QTime time;
+    QElapsedTimer time;
     void update()
     {
         if (time.elapsed() >= 1000) {
@@ -261,7 +260,7 @@ FormProgressDialog::FormProgressDialog(const QString &caption, const QString &la
     //item->setIcon( QIcon::fromTheme(iconname) );
     widget = item->widget();
     QVBoxLayout *layout = new QVBoxLayout(widget);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     widget->setLayout(layout);
 
     d->browser = new QTextBrowser(this);
@@ -455,7 +454,7 @@ static KPageWidgetItem *formAddPage(KPageDialog *dialog, const QString &name, co
     QWidget *widget = new QWidget(dialog);
     QVBoxLayout *boxlayout = new QVBoxLayout(widget);
     boxlayout->setSpacing(0);
-    boxlayout->setMargin(0);
+    boxlayout->setContentsMargins(0, 0, 0, 0);
     widget->setLayout(boxlayout);
 
     KPageWidgetItem *item = dialog->addPage(widget, name);
@@ -631,7 +630,7 @@ class UiLoader : public QUiLoader
 {
 public:
     UiLoader() : QUiLoader() {}
-    virtual ~UiLoader() {}
+    ~UiLoader() override {}
 
     /*
     virtual QAction* createAction(QObject* parent = 0, const QString& name = QString())
@@ -875,3 +874,4 @@ QObject *FormModule::loadPart(QWidget *parent, const QString &name, const QUrl &
     return part;
 }
 
+#include "moc_form.cpp"
