@@ -26,15 +26,14 @@
 #include <kross/core/actioncollection.h>
 #include <kross/core/interpreter.h>
 
-#include <QtWidgets/QAction>
-#include <QtWidgets/QBoxLayout>
-#include <QtCore/QDir>
-#include <QtCore/QFileInfo>
-#include <QtWidgets/QHeaderView>
-#include <QtWidgets/QLabel>
-#include <QtWidgets/QLineEdit>
-#include <QtWidgets/QPushButton>
-#include <QtWidgets/QTreeView>
+#include <QAction>
+#include <QBoxLayout>
+#include <QDir>
+#include <QFileInfo>
+#include <QHeaderView>
+#include <QLabel>
+#include <QLineEdit>
+#include <QPushButton>
 
 #include <kmessagebox.h>
 #include <kpagedialog.h>
@@ -168,7 +167,7 @@ void ActionCollectionEditor::initGui()
     QWidget *w = new QWidget(this);
     mainlayout->addWidget(w);
     QGridLayout *gridlayout = new QGridLayout();
-    gridlayout->setMargin(0);
+    gridlayout->setContentsMargins(0, 0, 0, 0);
     //gridlayout->setSpacing(0);
     w->setLayout(gridlayout);
 
@@ -198,7 +197,7 @@ void ActionCollectionEditor::initGui()
     gridlayout->addWidget(iconlabel, 3, 0);
     QWidget *iconbox = new QWidget(w);
     QHBoxLayout *iconlayout = new QHBoxLayout();
-    iconlayout->setMargin(0);
+    iconlayout->setContentsMargins(0, 0, 0, 0);
     iconbox->setLayout(iconlayout);
     d->iconedit = new QLineEdit(iconbox);
     iconlabel->setBuddy(d->iconedit);
@@ -244,7 +243,7 @@ void ActionCollectionEditor::initGui()
         //InterpreterInfo* info = Manager::self().interpreterInfo( Manager::self().interpreternameForFile( d->action->file() ) );
         //const QString defaultmime = info ? info->mimeTypes().join(" ").trimmed() : QString();
 
-        d->fileedit->fileDialog()->setMimeTypeFilters(mimetypes);
+        d->fileedit->setMimeTypeFilters(mimetypes);
         d->fileedit->setMode(KFile::File | KFile::ExistingOnly | KFile::LocalOnly);
         d->fileedit->setUrl(QUrl::fromLocalFile(d->action->file()));
         gridlayout->addWidget(d->fileedit, 5, 1);
@@ -566,7 +565,7 @@ void ActionCollectionView::slotAdd()
 {
 
 //TODO
-    KMessageBox::sorry(nullptr, "TODO");
+    KMessageBox::error(nullptr, "TODO");
 
 //ScriptManagerAddWizard wizard(this, collection);
 //int result = wizard.exec();
@@ -581,7 +580,7 @@ void ActionCollectionView::slotAdd()
             continue;
         }
         if (ActionCollectionModel::action(index)) {
-            //TODO propably add the item right after the current selected one?
+            //TODO probably add the item right after the current selected one?
             QModelIndex parent = index;
             while (parent.isValid() && ! collection) {
                 parent = d->view->model()->parent(parent);
@@ -606,6 +605,7 @@ void ActionCollectionView::slotRemove()
     if (! selectionModel()) {
         return;
     }
-    KMessageBox::sorry(nullptr, "TODO");
+    KMessageBox::error(nullptr, "TODO");
 }
 
+#include "moc_actioncollectionview.cpp"
